Skip to contents

This function pulls information (length, area, shape, etc.) about number of bio regions. For a list of available options visit https://open.canada.ca/data/en/dataset/23eb8b56-dac8-4efc-be7c-b8fa11ba62e9

Usage

data_bioregion(bioregion = "Scotian Shelf")

Arguments

bioregion

name of the bio region to match from the NAME_E column from Open Data or one of the Ocean Basins to return multiple bioregions (i.e. "Atlantic", "Arctic", or "Pacific) or "All" to return all available bioregions. Default is "Scotian Shelf"

Value

sf data.frame

Examples

if (FALSE) { # \dontrun{
bioregion <- data_bioregion()
} # }