Get Objectives from Canadian Protected and Conserved Areas
Source:R/data_objectives.R
data_objectives.RdThis function gets site and network level objectives for the Canadian protected and conserved areas in the Scotian Shelf bio region.
Usage
data_objectives(
type = NULL,
area = "St. Anns Bank Marine Protected Area",
prohibiton = FALSE
)